==> jbizmo-commons-selenium-2.7.0-sources.jar: net/sourceforge/jbizmo/commons/selenium/driver/IDriverProducer.java <==
/*
 * This file is part of JBizMo, a set of tools, libraries and plug-ins
 * for modeling and creating Java-based enterprise applications.
 * For more information visit:
 *
 * http://sourceforge.net/projects/jbizmo/
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.sourceforge.jbizmo.commons.selenium.driver;

import net.sourceforge.jbizmo.commons.selenium.util.SeleniumTestProperties;

import org.openqa.selenium.WebDriver;

/**
 * <p>
 * Interface that defines the functionality of a producer for Selenium WebDriver objects.
 * </p>
 * <p>
 * Copyright 2017 (C) by Martin Ganserer
 * </p>
 * @author Martin Ganserer
 * @version 1.0.0
 */
public interface IDriverProducer
{
	/**
	 * @return the Selenium WebDriver instance
	 */
	WebDriver getDriverInstance();

	/**
	 * @param properties
	 */
	void setProperties(SeleniumTestProperties properties);
}

==> jbizmo-commons-selenium-4.0.0-sources.jar: net/sourceforge/jbizmo/commons/selenium/driver/IDriverProducer.java <==
/*
 * This file is part of JBizMo, a set of tools, libraries and plug-ins
 * for modeling and creating Java-based enterprise applications.
 * For more information visit:
 *
 * http://sourceforge.net/projects/jbizmo/
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.sourceforge.jbizmo.commons.selenium.driver;

import net.sourceforge.jbizmo.commons.selenium.util.SeleniumTestProperties;

import org.openqa.selenium.WebDriver;

/**
 * <p>
 * Interface that defines the functionality of a producer for Selenium WebDriver objects
 * </p>
 * <p>
 * Copyright 2017 (C) by Martin Ganserer
 * </p>
 * @author Martin Ganserer
 * @version 1.0.0
 */
public interface IDriverProducer
{
	/**
	 * @return the Selenium WebDriver instance
	 */
	WebDriver getDriverInstance();

	/**
	 * @param properties
	 */
	void setProperties(SeleniumTestProperties properties);

}
